about summary refs log tree commit diff stats
path: root/src/jabber.c
diff options
context:
space:
mode:
authorJames Booth <boothj5@gmail.com>2013-01-23 22:49:46 +0000
committerJames Booth <boothj5@gmail.com>2013-01-23 22:49:46 +0000
commite4b653057ad90bffdfd0f37a5af9fffe6bddd834 (patch)
tree107c36e591359fbe6e03595c3b99f4864b1ee858 /src/jabber.c
parente325c391c5dbaa07c22a62e11ce9759b8e49f24b (diff)
downloadprofani-tty-e4b653057ad90bffdfd0f37a5af9fffe6bddd834.tar.gz
Renamed disco handlers -> caps handlers
Diffstat (limited to 'src/jabber.c')
-rw-r--r--src/jabber.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/jabber.c b/src/jabber.c
index f68327fb..1d8606fe 100644
--- a/src/jabber.c
+++ b/src/jabber.c
@@ -85,9 +85,9 @@ static int _iq_handler(xmpp_conn_t * const conn,
     xmpp_stanza_t * const stanza, void * const userdata);
 static int _roster_handler(xmpp_conn_t * const conn,
     xmpp_stanza_t * const stanza, void * const userdata);
-static int _disco_response_handler(xmpp_conn_t * const conn, xmpp_stanza_t * const stanza,
+static int _caps_response_handler(xmpp_conn_t * const conn, xmpp_stanza_t * const stanza,
     void * const userdata);
-static int _disco_request_handler(xmpp_conn_t * const conn, xmpp_stanza_t * const stanza,
+static int _caps_request_handler(xmpp_conn_t * const conn, xmpp_stanza_t * const stanza,
     void * const userdata);
 static int _version_request_handler(xmpp_conn_t * const conn, xmpp_stanza_t * const stanza,
     void * const userdata);
@@ -811,14 +811,14 @@ _iq_handler(xmpp_conn_t * const conn,
     if (g_strcmp0(id, "roster") == 0) {
         return _roster_handler(conn, stanza, userdata);
 
     // handle disco responses
     } else if ((id != NULL) && (g_str_has_prefix(id, "disco")) &&
             (g_strcmp0(type, "result") == 0)) {
-        return _disco_response_handler(conn, stanza, userdata);
+        return _caps_response_handler(conn, stanza, userdata);
 
     // handle disco requests
     } else if (stanza_is_caps_request(stanza)) {
-        return _disco_request_handler(conn, stanza, userdata);
+        return _caps_request_handler(conn, stanza, userdata);
 
     } else if (stanza_is_version_request(stanza)) {
         return _version_request_handler(conn, stanza, userdata);
@@ -1006,7 +1006,7 @@ _version_request_handler(xmpp_conn_t * const conn, xmpp_stanza_t * const stanza,
 }
 
 static int
-_disco_request_handler(xmpp_conn_t * const conn, xmpp_stanza_t * const stanza,
+_caps_request_handler(xmpp_conn_t * const conn, xmpp_stanza_t * const stanza,
     void * const userdata)
 {
     xmpp_ctx_t *ctx = (xmpp_ctx_t *)userdata;
@@ -1033,7 +1033,7 @@ _disco_request_handler(xmpp_conn_t * const conn, xmpp_stanza_t * const stanza,
 }
 
 static int
-_disco_response_handler(xmpp_conn_t * const conn, xmpp_stanza_t * const stanza,
+_caps_response_handler(xmpp_conn_t * const conn, xmpp_stanza_t * const stanza,
     void * const userdata)
 {
     char *type = xmpp_stanza_get_type(stanza);
@@ -811,14 +811,14 @@ _iq_handler(xmpp_conn_t * const conn,
         return _roster_handler(conn, stanza, userdata);
 
-    // handle disco responses
+    // handle caps responses
     } else if ((id != NULL) && (g_str_has_prefix(id, "disco")) &&
             (g_strcmp0(type, "result") == 0)) {
@@ -811,14 +811,14 @@ _iq_handler(xmpp_conn_t * const conn,
 
-    // handle disco requests
+    // handle caps requests
     } else if (stanza_is_caps_request(stanza)) {